@@ -1,5 +1,15 @@
 var NAVTREEINDEX6 =
 {
+"stream_8c.html#ac9d87c5da34f1357637309ffdd1185cb":[11,0,61,20],
+"stream_8c.html#ad05e907fadaaa1cd21062cd0bb8701a1":[11,0,61,30],
+"stream_8c.html#ad5e65901bc4e01fe66908de6eb983b74":[11,0,61,19],
+"stream_8c.html#ae19fa7dc034a052b0ee1f582e8a949c0":[11,0,61,13],
+"stream_8c.html#ae8a3753316267cd885e875ae7fbd3c91":[11,0,61,26],
+"stream_8c.html#aebbd77924da3cf1c98f8552178f42da6":[11,0,61,15],
+"stream_8c.html#af86bc65adf0e4c18f8ea3c09f5e62d9d":[11,0,61,31],
+"stream_8c.html#afeafcb95f3bc48b81410bf7848473a8f":[11,0,61,14],
+"stream_8h.html":[11,0,62],
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106":[11,0,62,5],
 "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b":[11,0,62,5,2],
 "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a615348212b647ad5d30313536ed6e125":[11,0,62,5,3],
 "stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a73692ffb4a18142df04772cf3783410c":[11,0,62,5,4],
@@ -35,13 +45,14 @@ var NAVTREEINDEX6 =
 "structbuffer.html#a89e90c78766d7752205fc656265fcf6d":[10,0,0,2],
 "structbuffer.html#aa44533c5c02fdb7e3a6a871e15cbc6ff":[10,0,0,1],
 "structcontrol.html":[10,0,1],
-"structcontrol.html#a0007c2838ce6bfcae3b70e79afa47882":[10,0,1,5],
-"structcontrol.html#a7692004aa39ce745bf1adfaa0df538f3":[10,0,1,6],
-"structcontrol.html#a92ce8cd45f48c1ec27c2f7c79ec82a93":[10,0,1,4],
-"structcontrol.html#aa9141611498aca4de42a787f5275ccc9":[10,0,1,1],
-"structcontrol.html#aded6eaccaea7665d8226a8d9caca5278":[10,0,1,3],
-"structcontrol.html#aea2a5224a07931eb7decb7438de18ad7":[10,0,1,2],
-"structcontrol.html#afc1575acdac04527753a78ff0383ee92":[10,0,1,0],
+"structcontrol.html#a0007c2838ce6bfcae3b70e79afa47882":[10,0,1,6],
+"structcontrol.html#a7692004aa39ce745bf1adfaa0df538f3":[10,0,1,7],
+"structcontrol.html#a92ce8cd45f48c1ec27c2f7c79ec82a93":[10,0,1,5],
+"structcontrol.html#aa9141611498aca4de42a787f5275ccc9":[10,0,1,2],
+"structcontrol.html#aded6eaccaea7665d8226a8d9caca5278":[10,0,1,4],
+"structcontrol.html#aea2a5224a07931eb7decb7438de18ad7":[10,0,1,3],
+"structcontrol.html#aed9a36f0e4fedd43932feedf499a15a4":[10,0,1,0],
+"structcontrol.html#afc1575acdac04527753a78ff0383ee92":[10,0,1,1],
 "structdata.html":[10,0,2],
 "structdata.html#a26f2e420b61d6dfdc6422c9d3494f69e":[10,0,2,0],
 "structdata.html#a9557370cbf3e47913eb5e8366574f15e":[10,0,2,1],
@@ -84,9 +95,12 @@ var NAVTREEINDEX6 =
 "structhandle.html#ab5ff56d8bdb0a9de5c998515c4021fbc":[10,0,5,4],
 "structhandle.html#aff4be9c1d70007974cdb9c13c04dd0ac":[10,0,5,1],
 "structimpl.html":[10,0,6],
-"structimpl.html#a485c133db4c8c2a7764aa6d6a80ed2c9":[10,0,6,0],
-"structimpl.html#a4a964874ac5b087263c7f37ca43ea536":[10,0,6,2],
-"structimpl.html#a6eaec9ea671abe6434946657ac2f1bae":[10,0,6,1],
+"structimpl.html#a1fbd22bf7a25dba52ebfb4fde6354f74":[10,0,6,2],
+"structimpl.html#a485c133db4c8c2a7764aa6d6a80ed2c9":[10,0,6,1],
+"structimpl.html#a4a964874ac5b087263c7f37ca43ea536":[10,0,6,5],
+"structimpl.html#a6eaec9ea671abe6434946657ac2f1bae":[10,0,6,4],
+"structimpl.html#ac57b1d03dd1a743e0bc038c295531aba":[10,0,6,0],
+"structimpl.html#ae5d9d7e2bec44ef00dcdbf60cfc99e8c":[10,0,6,3],
 "structlog__ctx.html":[10,0,7],
 "structlog__ctx.html#a07c4dbcebb9171d1b38fc5cebe8c69f0":[10,0,7,3],
 "structlog__ctx.html#a823ad979b6ad1716910faa4cc51a3644":[10,0,7,2],
@@ -235,19 +249,5 @@ var NAVTREEINDEX6 =
 "structpw__core__methods.html#a460ee1de46fe6e281c576cbe54841309":[10,0,29,2],
 "structpw__core__methods.html#a47721985e4d0b24474f5598d0d94b6c5":[10,0,29,5],
 "structpw__core__methods.html#a7e77a9289cd4ba827a7082109d207459":[10,0,29,1],
-"structpw__core__methods.html#a96ae294d1a899b90a6a8d3458a300fe2":[10,0,29,4],
-"structpw__core__methods.html#aa5ee0b92d1e85c741adcaa93a04622fa":[10,0,29,3],
-"structpw__core__methods.html#ab64487c2ddac4c7d315cc54a4d5b7176":[10,0,29,7],
-"structpw__core__methods.html#af1831e5a0a805bf3ed47e48dbd09ee3a":[10,0,29,8],
-"structpw__data__loop__events.html":[10,0,31],
-"structpw__data__loop__events.html#a19c5624deda8fb2d4fd452bf6ba6c3b8":[10,0,31,1],
-"structpw__data__loop__events.html#a5ee1e79472b7ab5aab28d40df7a1db0b":[10,0,31,0],
-"structpw__device__events.html":[10,0,32],
-"structpw__device__events.html#a01a060fea8c0b9d8ccd4eb2aff2848e6":[10,0,32,0],
-"structpw__device__events.html#a75a9ec87b680ae9f45503fbbc1b0fcc9":[10,0,32,1],
-"structpw__device__events.html#adbe2ffa9bd2bcf75f82ce7cfd99ebb29":[10,0,32,2],
-"structpw__device__info.html":[10,0,33],
-"structpw__device__info.html#a05bdd1fb2e89f763b27fe8784cb3e5c2":[10,0,33,1],
-"structpw__device__info.html#a3c53740de36a82a69153911b6777f66e":[10,0,33,0],
-"structpw__device__info.html#a8167e42a1f2bebaddedd6987b9dd39ac":[10,0,33,4]
+"structpw__core__methods.html#a96ae294d1a899b90a6a8d3458a300fe2":[10,0,29,4]
 };
